@@ -1,4 +1,4 @@
-from typing import cast, Tuple, TYPE_CHECKING, Union
+from typing import cast, List, Optional, Tuple, TYPE_CHECKING, Union
 
 if TYPE_CHECKING:
     from .console import (
@@ -19,7 +19,7 @@ PaddingDimensions = Union[int, Tuple[int], Tuple[int, int], Tuple[int, int, int,
 class Padding(JupyterMixin):
     """Draw space around content.
 
-    Example:        
+    Example:
         >>> print(Padding("Hello", (2, 4), style="on blue"))
 
     Args:
@@ -79,7 +79,6 @@ class Padding(JupyterMixin):
     def __rich_console__(
         self, console: "Console", options: "ConsoleOptions"
     ) -> "RenderResult":
-
         style = console.get_style(self.style)
         if self.expand:
             width = options.max_width
@@ -90,30 +89,50 @@ class Padding(JupyterMixin):
                 + self.right,
                 options.max_width,
             )
-        child_options = options.update(width=width - self.left - self.right)
-        lines = console.render_lines(self.renderable, child_options, style=style)
-        lines = Segment.set_shape(lines, child_options.max_width, style=style)
+        lines = console.render_lines(
+            self.renderable,
+            options.update_width(width - self.left - self.right),
+            style=style,
+            pad=True,
+        )
+        _Segment = Segment
 
-        blank_line = Segment(" " * width + "\n", style)
-        top = [blank_line] * self.top
-        bottom = [blank_line] * self.bottom
-        left = Segment(" " * self.left, style) if self.left else None
-        right = Segment(" " * self.right, style) if self.right else None
-        new_line = Segment.line()
-        yield from top
-        for line in lines:
-            if left is not None:
+        left = _Segment(" " * self.left, style) if self.left else None
+        right = (
+            [_Segment(f'{" " * self.right}', style), _Segment.line()]
+            if self.right
+            else [_Segment.line()]
+        )
+        blank_line: Optional[List[Segment]] = None
+        if self.top:
+            blank_line = [_Segment(f'{" " * width}\n', style)]
+            yield from blank_line * self.top
+        if left:
+            for line in lines:
                 yield left
-            yield from line
-            if right is not None:
-                yield right
-            yield new_line
-        yield from bottom
+                yield from line
+                yield from right
+        else:
+            for line in lines:
+                yield from line
+                yield from right
+        if self.bottom:
+            blank_line = blank_line or [_Segment(f'{" " * width}\n', style)]
+            yield from blank_line * self.bottom
 
     def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
         extra_width = self.left + self.right
-        min_width, max_width = Measurement.get(
-            console, self.renderable, max(1, max_width - extra_width)
+        if max_width - extra_width < 1:
+            return Measurement(max_width, max_width)
+        measure_min, measure_max = Measurement.get(
+            console, self.renderable, max(0, max_width - extra_width)
         )
-        render_width = Measurement(min_width + extra_width, max_width + extra_width)
-        return render_width
+        measurement = Measurement(measure_min + extra_width, measure_max + extra_width)
+        measurement = measurement.with_maximum(max_width)
+        return measurement
+
+
+if __name__ == "__main__":  #  pragma: no cover
+    from rich import print
+
+    print(Padding("Hello, World", (2, 4), style="on blue"))
